==> ozacc-mail-1.0-src.tar.gz: ozacc-mail-1.0/src/java/com/ozacc/mail/Mail.java <==
package com.ozacc.mail;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;

/**
 * ᡼롣
 * 
 * @author Tomohiro Otsuka
 * @version $Id: Mail.java,v 1.4 2004/09/10 22:41:42 otsuka Exp $
 */
public class Mail {

	/** <code>ISO-2022-JP</code> */
	public static final String JIS_CHARSET = "ISO-2022-JP";

	private String charset = JIS_CHARSET;

	private String text;

	private InternetAddress from;

	private String subject;

	private List to;

	private List cc;

	private List bcc;

	private InternetAddress returnPath;

	private InternetAddress replyTo;

	private String importance;

	private Map xHeaders;

	/**
	 * 󥹥ȥ饯
	 */
	public Mail() {}

	/**
	 * 󥹥ȥ饯
	 * 亹пͤ̾򥨥󥳡ɤ˻Ѥʸɤꤷޤ
	 * ǥեȤ<code>ISO-2022-JP</code>Ǥ
	 * <p>
	 * ܸĶѤ̾ѹɬפϤޤ
	 * 
	 * @param charset 󥳡ɤ˻Ѥʸ
	 */
	public Mail(String charset) {
		this();
		this.charset = charset;
	}

	/**
	 * 󥳡ɤ˻Ѥʸɤ֤ޤ
	 * 
	 * @return 󥳡ɤ˻Ѥʸ
	 */
	public String getCharset() {
		return charset;
	}

	/**
	 * ᡼ν٤򥻥åȤޤ
	 * ǻǽͤϡhighסnormalסlowפΤ줫Ǥ
	 * 
	 * @param importance ᡼ν١highסnormalסlowפΤ줫
	 * @throws IllegalArgumentException ǽͰʳꤵ줿
	 * 
	 * @see Mail.Importance
	 */
	public void setImportance(String importance) throws IllegalArgumentException {
		if ("high".equals(importance) || "normal".equals(importance) || "low".equals(importance)) {
			this.importance = importance;
		} else {
			throw new IllegalArgumentException("'" + importance + "'ϡ᡼٤ˤϻǤʤͤǤ");
		}
	}

	/**
	 * ᡼ν٤֤ޤ
	 * ͤϡhighסnormalסlowפΤ줫Ǥ
	 * 
	 * @return ᡼ν١highסnormalסlowפΤ줫
	 */
	public String getImportance() {
		return importance;
	}

	/**
	 * ᡼襢ɥ쥹ɲäޤ
	 * 
	 * @param address 襢ɥ쥹
	 */
	public void addTo(InternetAddress address) {
		if (to == null) {
			to = new ArrayList();
		}
		to.add(address);
	}

	/**
	 * ᡼襢ɥ쥹ɲäޤ
	 * 
	 * @param email 襢ɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addTo(String email) throws IllegalArgumentException {
		try {
			addTo(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼̾ȥɥ쥹ɲäޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email 襢ɥ쥹
	 * @param name ̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addTo(String email, String name) throws IllegalArgumentException {
		try {
			addTo(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼襢ɥ쥹֤ޤ
	 * 襢ɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return 襢ɥ쥹
	 */
	public InternetAddress[] getTo() {
		if (to == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])to.toArray(new InternetAddress[to.size()]);
	}

	/**
	 * CCɥ쥹ɲäޤ
	 * 
	 * @param address CCΥɥ쥹
	 */
	public void addCc(InternetAddress address) {
		if (cc == null) {
			cc = new ArrayList();
		}
		cc.add(address);
	}

	/**
	 * CCɥ쥹ɲäޤ
	 * 
	 * @param email CCΥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addCc(String email) throws IllegalArgumentException {
		try {
			addCc(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * CCΰ̾ȥɥ쥹ɲäޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email CCΥɥ쥹
	 * @param name CCΰ̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addCc(String email, String name) throws IllegalArgumentException {
		try {
			addCc(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼CCɥ쥹֤ޤ
	 * CCɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return CCɥ쥹
	 */
	public InternetAddress[] getCc() {
		if (cc == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])cc.toArray(new InternetAddress[cc.size()]);
	}

	/**
	 * BCCɥ쥹ɲäޤ
	 * 
	 * @param address BCCΥɥ쥹
	 */
	public void addBcc(InternetAddress address) {
		if (bcc == null) {
			bcc = new ArrayList();
		}
		bcc.add(address);
	}

	/**
	 * BCCɥ쥹ɲäޤ
	 * 
	 * @param email BCCΥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addBcc(String email) throws IllegalArgumentException {
		try {
			addBcc(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼BCCɥ쥹֤ޤ
	 * BCCɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return BCCɥ쥹
	 */
	public InternetAddress[] getBcc() {
		if (bcc == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])bcc.toArray(new InternetAddress[bcc.size()]);
	}

	/**
	 * ᡼κпͥɥ쥹򥻥åȤޤ
	 * 
	 * @param address пͥɥ쥹
	 */
	public void setFrom(InternetAddress address) {
		from = address;
	}

	/**
	 * ᡼κпͥɥ쥹򥻥åȤޤ
	 * 
	 * @param email пͥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setFrom(String email) throws IllegalArgumentException {
		try {
			setFrom(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼κп̾ȥɥ쥹򥻥åȤޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email пͥɥ쥹
	 * @param name п̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setFrom(String email, String name) throws IllegalArgumentException {
		try {
			setFrom(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼κпͥɥ쥹֤ޤåȤƤʤnull֤ޤ
	 * 
	 * @return ᡼κпͥɥ쥹
	 */
	public InternetAddress getFrom() {
		return from;
	}

	/**
	 * Return-Pathɥ쥹򥻥åȤޤ
	 * 
	 * @param address Return-Pathɥ쥹
	 */
	public void setReturnPath(InternetAddress address) {
		returnPath = address;
	}

	/**
	 * Return-Pathɥ쥹򥻥åȤޤ
	 * 
	 * @param email Return-Pathɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setReturnPath(String email) throws IllegalArgumentException {
		try {
			setReturnPath(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * Return-Pathɥ쥹֤ޤ
	 * 
	 * @return Return-Pathɥ쥹
	 */
	public InternetAddress getReturnPath() {
		return returnPath;
	}

	/**
	 * ֿ襢ɥ쥹򥻥åȤޤ
	 * 
	 * @param address ֿ襢ɥ쥹
	 */
	public void setReplyTo(InternetAddress address) {
		replyTo = address;
	}

	/**
	 * ֿ襢ɥ쥹򥻥åȤޤ
	 * 
	 * @param email ֿ襢ɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setReplyTo(String email) throws IllegalArgumentException {
		try {
			setReplyTo(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼ֿ襢ɥ쥹֤ޤåȤƤʤnull֤ޤ
	 * 
	 * @return ֿ襢ɥ쥹
	 */
	public InternetAddress getReplyTo() {
		return replyTo;
	}

	/**
	 * ᡼η֤̾ޤåȤƤʤ϶ʸ֤ޤ
	 * 
	 * @return ᡼η̾
	 */
	public String getSubject() {
		if (subject == null) {
			return "";
		}
		return subject;
	}

	/**
	 * ᡼η̾򥻥åȤޤ
	 * 
	 * @param subject ᡼η̾
	 */
	public void setSubject(String subject) {
		this.subject = subject;
	}

	/**
	 * ᡼ʸ֤ޤ
	 * ʸåȤƤʤ϶ʸ֤ޤ
	 * 
	 * @return ᡼ʸ
	 */
	public String getText() {
		if (text == null) {
			return "";
		}
		return text;
	}

	/**
	 * ᡼ʸ򥻥åȤޤ
	 * 
	 * @param text ᡼ʸ
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * ᡼إåǤդΥإåɲäޤ
	 * ǤեإåϡX-key: valueפΥեޥåȤǥ᡼إåȤ߹ޤޤ
	 *  
	 * @param key Ǥեإå̾Ƭ"X-"ǻϤޤäƤʤСưŪͿޤ
	 * @param value Ǥեإå
	 */
	public void addXHeader(String key, String value) {
		if (xHeaders == null) {
			xHeaders = new HashMap();
		}
		if (key.startsWith("X-")) {
			xHeaders.put(key, value);
		} else {
			xHeaders.put("X-" + key, value);
		}
	}

	/**
	 * ᡼Ǥեإå̾ͤMap󥹥󥹤֤ޤ
	 * Ǥեإå⥻åȤƤʤȤnull֤ޤ
	 * <p>
	 * Map󥹥󥹤ؤνϤǤޤ(unmodifiableMapˤʤäƤޤ)
	 * 
	 * @return ᡼Ǥեإå̾ͤMap󥹥󥹡ޤnull
	 */
	public Map getXHeaders() {
		if (xHeaders == null) {
			return null;
		}
		return Collections.unmodifiableMap(xHeaders);
	}

	/**
	 * ᡼ƤϤޤ<br>
	 * ᡼Υ˻եޥåȤǽϤޤ
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		StringBuffer buf = new StringBuffer(1000);
		buf.append("Mail\n");
		buf.append("Return-Path: ").append(returnPath).append("\n");
		buf.append("From: ").append(from != null ? from.toUnicodeString() : null).append("\n");
		buf.append("To: ").append(arrayToCommaDelimitedString(to)).append("\n");
		buf.append("Cc: ").append(arrayToCommaDelimitedString(cc)).append("\n");
		buf.append("Bcc: ").append(arrayToCommaDelimitedString(bcc)).append("\n");
		buf.append("Subject: ").append(subject).append("\n");

		if (xHeaders != null) {
			for (Iterator itr = xHeaders.keySet().iterator(); itr.hasNext();) {
				String header = (String)itr.next();
				String value = (String)xHeaders.get(header);
				buf.append(header).append(": ").append(value).append("\n");
			}
		}

		buf.append("\n");
		buf.append(text);

		return buf.toString();
	}

	/**
	 * @param list
	 * @return 
	 */
	private String arrayToCommaDelimitedString(List list) {
		if (list == null) {
			return "null";
		} else {
			StringBuffer sb = new StringBuffer();
			for (int i = 0, num = list.size(); i < num; i++) {
				if (i > 0) {
					sb.append(", ");
				}
				sb.append(((InternetAddress)list.get(i)).toUnicodeString());
			}
			return sb.toString();
		}
	}

	/**
	 * ᡼ν١Τߤ
	 * 
	 * @author Tomohiro Otsuka
	 * @version $Id: Mail.java,v 1.4 2004/09/10 22:41:42 otsuka Exp $
	 */
	public static class Importance {

		/** ١ֹ */
		public static final String HIGH = "high";

		/** ١ */
		public static final String NORMAL = "normal";

		/** ١ */
		public static final String LOW = "low";

	}
}

==> ozacc-mail-1.0.1-src.tar.gz: ozacc-mail-1.0.1/src/java/com/ozacc/mail/Mail.java <==
package com.ozacc.mail;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;

/**
 * ᡼롣
 * 
 * @since 1.0
 * @author Tomohiro Otsuka
 * @version $Id: Mail.java,v 1.5 2004/09/13 07:10:35 otsuka Exp $
 */
public class Mail {

	/** <code>ISO-2022-JP</code> */
	public static final String JIS_CHARSET = "ISO-2022-JP";
	
	public static final String DOCTYPE_PUBLIC = "-//OZACC//DTD MAIL//EN";

	public static final String DOCTYPE_SYSTEM = "http://www.ozacc.com/library/dtd/ozacc-mail.dtd";

	private String charset = JIS_CHARSET;

	private String text;

	private InternetAddress from;

	private String subject;

	private List to;

	private List cc;

	private List bcc;

	private InternetAddress returnPath;

	private InternetAddress replyTo;

	private String importance;

	private Map xHeaders;

	/**
	 * 󥹥ȥ饯
	 */
	public Mail() {}

	/**
	 * 󥹥ȥ饯
	 * 亹пͤ̾򥨥󥳡ɤ˻Ѥʸɤꤷޤ
	 * ǥեȤ<code>ISO-2022-JP</code>Ǥ
	 * <p>
	 * ܸĶѤ̾ѹɬפϤޤ
	 * 
	 * @param charset 󥳡ɤ˻Ѥʸ
	 */
	public Mail(String charset) {
		this();
		this.charset = charset;
	}

	/**
	 * 󥳡ɤ˻Ѥʸɤ֤ޤ
	 * 
	 * @return 󥳡ɤ˻Ѥʸ
	 */
	public String getCharset() {
		return charset;
	}

	/**
	 * ᡼ν٤򥻥åȤޤ
	 * ǻǽͤϡhighסnormalסlowפΤ줫Ǥ
	 * 
	 * @param importance ᡼ν١highסnormalסlowפΤ줫
	 * @throws IllegalArgumentException ǽͰʳꤵ줿
	 * 
	 * @see Mail.Importance
	 */
	public void setImportance(String importance) throws IllegalArgumentException {
		if ("high".equals(importance) || "normal".equals(importance) || "low".equals(importance)) {
			this.importance = importance;
		} else {
			throw new IllegalArgumentException("'" + importance + "'ϡ᡼٤ˤϻǤʤͤǤ");
		}
	}

	/**
	 * ᡼ν٤֤ޤ
	 * ͤϡhighסnormalסlowפΤ줫Ǥ
	 * 
	 * @return ᡼ν١highסnormalסlowפΤ줫
	 */
	public String getImportance() {
		return importance;
	}

	/**
	 * ᡼襢ɥ쥹ɲäޤ
	 * 
	 * @param address 襢ɥ쥹
	 */
	public void addTo(InternetAddress address) {
		if (to == null) {
			to = new ArrayList();
		}
		to.add(address);
	}

	/**
	 * ᡼襢ɥ쥹ɲäޤ
	 * 
	 * @param email 襢ɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addTo(String email) throws IllegalArgumentException {
		try {
			addTo(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼̾ȥɥ쥹ɲäޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email 襢ɥ쥹
	 * @param name ̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addTo(String email, String name) throws IllegalArgumentException {
		try {
			addTo(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼襢ɥ쥹֤ޤ
	 * 襢ɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return 襢ɥ쥹
	 */
	public InternetAddress[] getTo() {
		if (to == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])to.toArray(new InternetAddress[to.size()]);
	}

	/**
	 * CCɥ쥹ɲäޤ
	 * 
	 * @param address CCΥɥ쥹
	 */
	public void addCc(InternetAddress address) {
		if (cc == null) {
			cc = new ArrayList();
		}
		cc.add(address);
	}

	/**
	 * CCɥ쥹ɲäޤ
	 * 
	 * @param email CCΥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addCc(String email) throws IllegalArgumentException {
		try {
			addCc(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * CCΰ̾ȥɥ쥹ɲäޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email CCΥɥ쥹
	 * @param name CCΰ̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addCc(String email, String name) throws IllegalArgumentException {
		try {
			addCc(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼CCɥ쥹֤ޤ
	 * CCɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return CCɥ쥹
	 */
	public InternetAddress[] getCc() {
		if (cc == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])cc.toArray(new InternetAddress[cc.size()]);
	}

	/**
	 * BCCɥ쥹ɲäޤ
	 * 
	 * @param address BCCΥɥ쥹
	 */
	public void addBcc(InternetAddress address) {
		if (bcc == null) {
			bcc = new ArrayList();
		}
		bcc.add(address);
	}

	/**
	 * BCCɥ쥹ɲäޤ
	 * 
	 * @param email BCCΥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void addBcc(String email) throws IllegalArgumentException {
		try {
			addBcc(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼BCCɥ쥹֤ޤ
	 * BCCɥ쥹⥻åȤƤʤȤ϶֤ޤ
	 * 
	 * @return BCCɥ쥹
	 */
	public InternetAddress[] getBcc() {
		if (bcc == null) {
			return new InternetAddress[0];
		}
		return (InternetAddress[])bcc.toArray(new InternetAddress[bcc.size()]);
	}

	/**
	 * ᡼κпͥɥ쥹򥻥åȤޤ
	 * 
	 * @param address пͥɥ쥹
	 */
	public void setFrom(InternetAddress address) {
		from = address;
	}

	/**
	 * ᡼κпͥɥ쥹򥻥åȤޤ
	 * 
	 * @param email пͥɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setFrom(String email) throws IllegalArgumentException {
		try {
			setFrom(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼κп̾ȥɥ쥹򥻥åȤޤ
	 * ̾JIS_CHARSETǥ󥳡ɤޤ
	 * 
	 * @param email пͥɥ쥹
	 * @param name п̾
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setFrom(String email, String name) throws IllegalArgumentException {
		try {
			setFrom(new InternetAddress(email, name, charset));
		} catch (UnsupportedEncodingException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼κпͥɥ쥹֤ޤåȤƤʤnull֤ޤ
	 * 
	 * @return ᡼κпͥɥ쥹
	 */
	public InternetAddress getFrom() {
		return from;
	}

	/**
	 * Return-Pathɥ쥹򥻥åȤޤ
	 * 
	 * @param address Return-Pathɥ쥹
	 */
	public void setReturnPath(InternetAddress address) {
		returnPath = address;
	}

	/**
	 * Return-Pathɥ쥹򥻥åȤޤ
	 * 
	 * @param email Return-Pathɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setReturnPath(String email) throws IllegalArgumentException {
		try {
			setReturnPath(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * Return-Pathɥ쥹֤ޤ
	 * 
	 * @return Return-Pathɥ쥹
	 */
	public InternetAddress getReturnPath() {
		return returnPath;
	}

	/**
	 * ֿ襢ɥ쥹򥻥åȤޤ
	 * 
	 * @param address ֿ襢ɥ쥹
	 */
	public void setReplyTo(InternetAddress address) {
		replyTo = address;
	}

	/**
	 * ֿ襢ɥ쥹򥻥åȤޤ
	 * 
	 * @param email ֿ襢ɥ쥹
	 * @throws IllegalArgumentException ʥեޥåȤΥɥ쥹ꤵ줿
	 */
	public void setReplyTo(String email) throws IllegalArgumentException {
		try {
			setReplyTo(new InternetAddress(email));
		} catch (AddressException e) {
			throw new IllegalArgumentException(e.getMessage());
		}
	}

	/**
	 * ᡼ֿ襢ɥ쥹֤ޤåȤƤʤnull֤ޤ
	 * 
	 * @return ֿ襢ɥ쥹
	 */
	public InternetAddress getReplyTo() {
		return replyTo;
	}

	/**
	 * ᡼η֤̾ޤåȤƤʤ϶ʸ֤ޤ
	 * 
	 * @return ᡼η̾
	 */
	public String getSubject() {
		if (subject == null) {
			return "";
		}
		return subject;
	}

	/**
	 * ᡼η̾򥻥åȤޤ
	 * 
	 * @param subject ᡼η̾
	 */
	public void setSubject(String subject) {
		this.subject = subject;
	}

	/**
	 * ᡼ʸ֤ޤ
	 * ʸåȤƤʤ϶ʸ֤ޤ
	 * 
	 * @return ᡼ʸ
	 */
	public String getText() {
		if (text == null) {
			return "";
		}
		return text;
	}

	/**
	 * ᡼ʸ򥻥åȤޤ
	 * 
	 * @param text ᡼ʸ
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * ᡼إåǤդΥإåɲäޤ
	 * ǤեإåϡX-key: valueפΥեޥåȤǥ᡼إåȤ߹ޤޤ
	 *  
	 * @param key Ǥեإå̾Ƭ"X-"ǻϤޤäƤʤСưŪͿޤ
	 * @param value Ǥեإå
	 */
	public void addXHeader(String key, String value) {
		if (xHeaders == null) {
			xHeaders = new HashMap();
		}
		if (key.startsWith("X-")) {
			xHeaders.put(key, value);
		} else {
			xHeaders.put("X-" + key, value);
		}
	}

	/**
	 * ᡼Ǥեإå̾ͤMap󥹥󥹤֤ޤ
	 * Ǥեإå⥻åȤƤʤȤnull֤ޤ
	 * <p>
	 * Map󥹥󥹤ؤνϤǤޤ(unmodifiableMapˤʤäƤޤ)
	 * 
	 * @return ᡼Ǥեإå̾ͤMap󥹥󥹡ޤnull
	 */
	public Map getXHeaders() {
		if (xHeaders == null) {
			return null;
		}
		return Collections.unmodifiableMap(xHeaders);
	}

	/**
	 * ᡼ƤϤޤ<br>
	 * ᡼Υ˻եޥåȤǽϤޤ
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		StringBuffer buf = new StringBuffer(1000);
		buf.append("Mail\n");
		buf.append("Return-Path: ").append(returnPath).append("\n");
		buf.append("From: ").append(from != null ? from.toUnicodeString() : null).append("\n");
		buf.append("To: ").append(arrayToCommaDelimitedString(to)).append("\n");
		buf.append("Cc: ").append(arrayToCommaDelimitedString(cc)).append("\n");
		buf.append("Bcc: ").append(arrayToCommaDelimitedString(bcc)).append("\n");
		buf.append("Subject: ").append(subject).append("\n");

		if (xHeaders != null) {
			for (Iterator itr = xHeaders.keySet().iterator(); itr.hasNext();) {
				String header = (String)itr.next();
				String value = (String)xHeaders.get(header);
				buf.append(header).append(": ").append(value).append("\n");
			}
		}

		buf.append("\n");
		buf.append(text);

		return buf.toString();
	}

	/**
	 * @param list
	 * @return 
	 */
	private String arrayToCommaDelimitedString(List list) {
		if (list == null) {
			return "null";
		} else {
			StringBuffer sb = new StringBuffer();
			for (int i = 0, num = list.size(); i < num; i++) {
				if (i > 0) {
					sb.append(", ");
				}
				sb.append(((InternetAddress)list.get(i)).toUnicodeString());
			}
			return sb.toString();
		}
	}

	/**
	 * ᡼ν١Τߤ
	 * 
	 * @author Tomohiro Otsuka
	 * @version $Id: Mail.java,v 1.5 2004/09/13 07:10:35 otsuka Exp $
	 */
	public static class Importance {

		/** ١ֹ */
		public static final String HIGH = "high";

		/** ١ */
		public static final String NORMAL = "normal";

		/** ١ */
		public static final String LOW = "low";

	}
}
